@@ -198,12 +198,13 @@ class EntryRepository extends EntityRepository
      * @param int    $since
      * @param string $tags
      * @param string $detail     'metadata' or 'full'. Include content field if 'full'
+     * @param string $domainName
      *
      * @todo Breaking change: replace default detail=full by detail=metadata in a future version
      *
      * @return Pagerfanta
      */
-    public function findEntries($userId, $isArchived = null, $isStarred = null, $isPublic = null, $sort = 'created', $order = 'asc', $since = 0, $tags = '', $detail = 'full')
+    public function findEntries($userId, $isArchived = null, $isStarred = null, $isPublic = null, $sort = 'created', $order = 'asc', $since = 0, $tags = '', $detail = 'full', $domainName = '')
     {
         if (!\in_array(strtolower($detail), ['full', 'metadata'], true)) {
             throw new \Exception('Detail "' . $detail . '" parameter is wrong, allowed: full or metadata');
@@ -242,7 +243,7 @@ class EntryRepository extends EntityRepository
                 $entryAlias = 'e' . $i;
                 $tagAlias = 't' . $i;
 
-                // Complexe queries to ensure multiple tags are associated to an entry
+                // Complex queries to ensure multiple tags are associated to an entry
                 // https://stackoverflow.com/a/6638146/569101
                 $qb->andWhere($qb->expr()->in(
                     'e.id',
@@ -258,6 +259,10 @@ class EntryRepository extends EntityRepository
             }
         }
 
+        if (\is_string($domainName) && '' !== $domainName) {
+            $qb->andWhere('e.domainName = :domainName')->setParameter('domainName', $domainName);
+        }
+
         if (!\in_array(strtolower($order), ['asc', 'desc'], true)) {
             throw new \Exception('Order "' . $order . '" parameter is wrong, allowed: asc or desc');
         }
