@@ -18,7 +18,7 @@ class RedisWorkerCommand extends ContainerAwareCommand
             ->setName('wallabag:import:redis-worker')
             ->setDescription('Launch Redis worker')
             ->addArgument('serviceName', InputArgument::REQUIRED, 'Service to use: wallabag_v1, wallabag_v2, pocket, readability, pinboard, delicious, firefox, chrome or instapaper')
-            ->addOption('maxIterations', '', InputOption::VALUE_OPTIONAL, 'Number of iterations before stoping', false)
+            ->addOption('maxIterations', '', InputOption::VALUE_OPTIONAL, 'Number of iterations before stopping', false)
         ;
     }
 
